@@ -3,7 +3,7 @@ package Tree::Simple::Visitor;
 use strict;
 use warnings;
 
-our $VERSION = '1.22';
+our $VERSION = '1.26';
 
 use Scalar::Util qw(blessed);
 
@@ -18,7 +18,8 @@ sub new {
 	my ($_class, $func, $depth) = @_;
 	if (defined($depth)){
 		($depth =~ /\d+/ && ($depth == RECURSIVE || $depth == CHILDREN_ONLY))
-			|| die "Insufficient Arguments : Depth arguement must be either RECURSIVE or CHILDREN_ONLY";
+                    || die "Insufficient Arguments : Depth arguement must be either ".
+                    "RECURSIVE or CHILDREN_ONLY";
 	}
 	my $class = ref($_class) || $_class;
     # if we have not supplied a $func
@@ -66,7 +67,7 @@ sub clearNodeFilter {
 sub setNodeFilter {
     my ($self, $filter_function) = @_;
 	(defined($filter_function) && ref($filter_function) eq "CODE")
-		|| die "Insufficient Arguments : filter function argument must be a subroutine reference";
+            || die "Insufficient Arguments : filter function argument must be a subroutine reference";
 	$self->{_filter_function} = $filter_function;
 }
 
@@ -89,7 +90,7 @@ sub getResults {
 sub visit {
 	my ($self, $tree) = @_;
 	(blessed($tree) && $tree->isa("Tree::Simple"))
-		|| die "Insufficient Arguments : You must supply a valid Tree::Simple object";
+            || die "Insufficient Arguments : You must supply a valid Tree::Simple object";
     # get all things set up
 	my @results;
 	my $func;
@@ -166,9 +167,13 @@ Tree::Simple::Visitor - Visitor object for Tree::Simple objects
 
 =head1 DESCRIPTION
 
-This object has been revised into what I think is more intelligent approach to Visitor objects. This is now a more suitable base class for building your own Visitors. It is also the base class for the visitors found in the B<Tree::Simple::VisitorFactory> distribution, which includes a number of useful pre-built Visitors.
+This object has been revised into what I think is more intelligent approach to Visitor objects.
+This is now a more suitable base class for building your own Visitors. It is also the base class
+for the visitors found in the B<Tree::Simple::VisitorFactory> distribution, which includes a
+number of useful pre-built Visitors.
 
-While I have changed a number of things about this module, I have kept it backwards compatible to the old way of using it. So the original example code still works:
+While I have changed a number of things about this module, I have kept it backwards compatible
+to the old way of using it. So the original example code still works:
 
   my @accumulator;
   my $visitor = Tree::Simple::Visitor->new(sub {
@@ -187,7 +192,8 @@ But is better expressed as this:
   $tree->accept($visitor);
   print join ", ", $visitor->getResults();  # prints "1.0, 2.0, 2.1.0, 3.0"
 
-This object is still pretty much a wrapper around the Tree::Simple C<traverse> method, and can be thought of as a depth-first traversal Visitor object.
+This object is still pretty much a wrapper around the Tree::Simple C<traverse> method,
+and can be thought of as a depth-first traversal Visitor object.
 
 =head1 METHODS
 
@@ -195,15 +201,34 @@ This object is still pretty much a wrapper around the Tree::Simple C<traverse> m
 
 =item B<new ($func, $depth)>
 
-The new style interface means that all arguments to the constructor are now optional. As a means of defining the usage of the old and new, when no arguments are sent to the constructor, it is assumed that the new style interface is being used. In the new style, the C<$depth> is always assumed to be equivalent to C<RECURSIVE> and the C<$func> argument can be set with C<setNodeFilter> instead. This is the recommended way of doing things now. If you have been using the old way, it is still there, and I will maintain backwards compatability for a few more version before removing it entirely. If you are using this module (and I don't even know if anyone actually is) you have been warned. Please contact me if this will be a problem.
+The new style interface means that all arguments to the constructor are now optional.
+As a means of defining the usage of the old and new, when no arguments are sent to the
+constructor, it is assumed that the new style interface is being used. In the new style,
+the C<$depth> is always assumed to be equivalent to C<RECURSIVE> and the C<$func> argument
+can be set with C<setNodeFilter> instead. This is the recommended way of doing things now.
+If you have been using the old way, it is still there, and I will maintain backwards
+compatibility for a few more version before removing it entirely. If you are using this
+module (and I do not even know if anyone actually is) you have been warned. Please contact
+me if this will be a problem.
 
 The old style constructor documentation is retained her for reference:
 
-The first argument to the constructor is a code reference to a function which expects a B<Tree::Simple> object as its only argument. The second argument is optional, it can be used to set the depth to which the function is applied. If no depth is set, the function is applied to the current B<Tree::Simple> instance. If C<$depth> is set to C<CHILDREN_ONLY>, then the function will be applied to the current B<Tree::Simple> instance and all its immediate children. If C<$depth> is set to C<RECURSIVE>, then the function will be applied to the current B<Tree::Simple> instance and all its immediate children, and all of their children recursively on down the tree. If no C<$depth> is passed to the constructor, then the function will only be applied to the current B<Tree::Simple> object and none of its children.
+The first argument to the constructor is a code reference to a function which expects a
+B<Tree::Simple> object as its only argument. The second argument is optional, it can be
+used to set the depth to which the function is applied. If no depth is set, the function
+is applied to the current B<Tree::Simple> instance. If C<$depth> is set to C<CHILDREN_ONLY>,
+then the function will be applied to the current B<Tree::Simple> instance and all its
+immediate children. If C<$depth> is set to C<RECURSIVE>, then the function will be applied
+to the current B<Tree::Simple> instance and all its immediate children, and all of their
+children recursively on down the tree. If no C<$depth> is passed to the constructor,
+then the function will only be applied to the current B<Tree::Simple> object and none
+ of its children.
 
 =item B<includeTrunk ($boolean)>
 
-Based upon the value of C<$boolean>, this will tell the visitor to collect the trunk of the tree as well. It is defaulted to false (C<0>) in the new style interface, but is defaulted to true (C<1>) in the old style interface.
+Based upon the value of C<$boolean>, this will tell the visitor to collect the trunk of the
+tree as well. It is defaulted to false (C<0>) in the new style interface, but is defaulted
+to true (C<1>) in the old style interface.
 
 =item B<getNodeFilter>
 
@@ -215,7 +240,10 @@ This method clears node filter field.
 
 =item B<setNodeFilter ($filter_function)>
 
-This method accepts a CODE reference as its C<$filter_function> argument. This code reference is used to filter the tree nodes as they are collected. This can be used to customize output, or to gather specific information from a more complex tree node. The filter function should accept a single argument, which is the current Tree::Simple object.
+This method accepts a CODE reference as its C<$filter_function> argument. This code reference
+is used to filter the tree nodes as they are collected. This can be used to customize output,
+or to gather specific information from a more complex tree node. The filter function should
+accept a single argument, which is the current Tree::Simple object.
 
 =item B<getResults>
 
@@ -223,11 +251,15 @@ This method returns the accumulated results of the application of the node filte
 
 =item B<setResults>
 
-This method should not really be used outside of this class, as it just would not make any sense to. It is included in this class and in this documenation to facilitate subclassing of this class for your own needs. If you desire to clear the results, then you can simply call C<setResults> with no argument.
+This method should not really be used outside of this class, as it just would not make any sense
+to. It is included in this class and in this documentation to facilitate subclassing of this
+class for your own needs. If you desire to clear the results, then you can simply call
+C<setResults> with no argument.
 
 =item B<visit ($tree)>
 
-The C<visit> method accepts a B<Tree::Simple> and applies the function set in C<new> or C<setNodeFilter> appropriately. The results of this application can be retrieved with C<getResults>
+The C<visit> method accepts a B<Tree::Simple> and applies the function set in C<new> or
+C<setNodeFilter> appropriately. The results of this application can be retrieved with C<getResults>
 
 =back
 
@@ -239,26 +271,36 @@ These constants are part of the old-style interface, and therefore will eventual
 
 =item B<RECURSIVE>
 
-If passed this constant in the constructor, the function will be applied recursively down the hierarchy of B<Tree::Simple> objects.
+If passed this constant in the constructor, the function will be applied recursively down the
+hierarchy of B<Tree::Simple> objects.
 
 =item B<CHILDREN_ONLY>
 
-If passed this constant in the constructor, the function will be applied to the immediate children of the B<Tree::Simple> object.
+If passed this constant in the constructor, the function will be applied to the immediate children
+of the B<Tree::Simple> object.
 
 =back
 
 =head1 BUGS
 
-None that I am aware of. The code is pretty thoroughly tested (see B<CODE COVERAGE> section in B<Tree::Simple>) and is based on an (non-publicly released) module which I had used in production systems for about 2 years without incident. Of course, if you find a bug, let me know, and I will be sure to fix it.
+None that I am aware of. The code is pretty thoroughly tested (see B<CODE COVERAGE> section in
+B<Tree::Simple>) and is based on an (non-publicly released) module which I had used in production
+systems for about 2 years without incident. Of course, if you find a bug, let me know, and I will
+be sure to fix it.
 
 =head1 SEE ALSO
 
-I have written a set of pre-built Visitor objects, available on CPAN as B<Tree::Simple::VisitorFactory>.
+I have written a set of pre-built Visitor objects, available on CPAN as
+B<Tree::Simple::VisitorFactory>.
 
 =head1 AUTHOR
 
 stevan little, E<lt>stevan@iinteractive.comE<gt>
 
+=head1 REPOSITORY
+
+L<https://github.com/ronsavage/Tree-Simple>.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2004-2006 by Infinity Interactive, Inc.
@@ -268,4 +310,4 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
